@@ -40,7 +40,7 @@ class FileSystem(ABC):
         pass
 
     @abstractmethod
-    def stat(self, path: str):
+    def stat(self, path: str, num_files_limit: int):
         pass
 
     @abstractmethod
@@ -55,6 +55,10 @@ class FileSystem(ABC):
     def read_excel(self, filename: str):
         pass
 
+    @abstractmethod
+    def read_csv(self, filename: str):
+        pass
+
     @abstractmethod
     def rm(self, paths: str):
         pass
@@ -143,23 +147,27 @@ class MinioFS(FileSystem):
         raise NotImplementedError("Tree list is not implemented for minio file system yet. Sorry ):")
         pass
 
-    def stat(self, path):
+    def stat(self, path: str, num_files_limit: int = -1):
         """
 
+        :param num_files_limit: Maximum number of files to return
         :param path: path to directory or file. If directory, it will stat for all files in the directory.
         :return:
         """
         file_attributes = []
+        num_files = 0
         bucket, prefix = self._process_path(path)
         for obj in self.__client__.list_objects(bucket, prefix=prefix, recursive=False):
+            num_files += 1
             file_attributes.append({
                 "name": obj.object_name,
                 "type": "folder" if obj.is_dir else "file",
                 "modified": datetime.strftime(obj.last_modified, "%Y-%m-%d %H:%M:%S"),
                 "size": obj.size,
             })
+            if num_files >= num_files_limit:
+                break
         return file_attributes
-        pass
 
     def find(self, path, filename):
         """
@@ -189,6 +197,15 @@ class MinioFS(FileSystem):
         data = self._stream_file(filename)
         return xlrd.open_workbook(file_contents=b''.join(data))
 
+    def read_csv(self, filename: str):
+        """
+        Reads filename and returns pandas DataFrame of the CSV
+        :param filename:
+        :return: pd.DataFrame
+        """
+        data = pd.read_csv(BytesIO(self.read_bytes(filename)), dtype=str)
+        return data
+
     def _process_path(self, path) -> (str, str):
         """
         Split path string into bucket and the prefix for usage in list_objects for the s3 api.
@@ -255,7 +272,6 @@ class MinioFS(FileSystem):
                                     length=len(csv_bytes), content_type='application/csv')
 
 
-
 class LocalFS(FileSystem):
     def lb(self, grep=None):
         """
@@ -299,16 +315,18 @@ class LocalFS(FileSystem):
                 # i.e. space because last, └── , above so no more |
                 yield from self.tree(path, prefix=prefix + extension)
 
-    def stat(self, path):
+    def stat(self, path: int, num_files_limit: int = -1):
         """
         Get file statistics for files in the directory
+        :param num_files_limit: Max number of files to return.
         :param path: path to directory
         :return: list of file statistics
         """
         file_attributes = []
-
         if Path(path).is_dir():
+            num_files = 0
             for file in Path(path).iterdir():
+                num_files += 1
                 stats = file.stat()
                 file_attributes.append({
                     "name": file.name,
@@ -317,6 +335,8 @@ class LocalFS(FileSystem):
                         datetime.fromtimestamp(stats.st_mtime, pytz.timezone("Asia/Singapore")), "%Y-%m-%d %H:%M:%S"),
                     "size": stats.st_size,
                 })
+                if num_files >= num_files_limit:
+                    break
         else:
             file = Path(path)
             stats = file.stat()
@@ -354,6 +374,15 @@ class LocalFS(FileSystem):
         """
         return xlrd.open_workbook(filename)
 
+    def read_csv(self, filename: str):
+        """
+        Reads filename and returns pandas DataFrame of the CSV
+        :param filename:
+        :return: pd.DataFrame
+        """
+        data = pd.read_csv(filename, dtype=str)
+        return data
+
     def rm(self, paths) -> None:
         if type(paths) != list:
             raise TypeError("Invalid type: paths is not a list.")
