@@ -1,6 +1,6 @@
 from datetime import datetime
 from unittest.mock import MagicMock
-
+import pandas as pd
 import pytest
 
 from unittest import mock
@@ -216,3 +216,23 @@ def test_cp(copysource, copyfile, MinioFileSystem, destination, source):
         MinioFileSystem.__client__.fget_object.assert_not_called()
         copyfile.assert_not_called()
         MinioFileSystem.__client__.fput_object.assert_not_called()
+
+
+@mock.patch('miniMinio.FileSystem.BytesIO')
+def test_minio_write_csv(bytesio, MinioFileSystem):
+    df = MagicMock()
+    csv_data = MagicMock()
+    csv_bytes = [1, 2, 3, 4]
+    csv_data.encode.return_value = csv_bytes
+    df.to_csv.return_value = csv_data
+    data = [1, 2, 3]
+    bytesio.return_value = data
+    MinioFileSystem.write_csv(df, 'bucket/folder/df.csv')
+    MinioFileSystem.__client__.put_object.assert_called_once_with('bucket', 'folder/df.csv', data=data,
+                                                                   length=len(csv_bytes), content_type='application/csv')
+
+
+def test_local_write_csv(LocalFileSystem):
+    df = MagicMock()
+    LocalFileSystem.write_csv(df, 'bucket/folder/df.csv')
+    df.to_csv.assert_called_once_with('bucket/folder/df.csv', index=None, header=None)
